# ordo
A lightweight feedback tool for Jupyter.

### Installation
Install and enable ordo on your Jupyter server

```
pip install ordo
jupyter nbextension install --py ordo
jupyter nbextension enable ordo --py
```

### Reference
Reference `README.ipynb` for a more thorough introduction to ordo.
